instrumenttools.TenorVoice
==========================

.. abjad-lineage:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice

.. autoclass:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.TenorVoice.TenorVoice.TenorVoice.__repr__
   :noindex:
